@@ -3,7 +3,7 @@ package X11::XCB::Event::ClientMessage;
 use Mouse;
 
 # XXX: the following are filled in by XS
-has [ 'response_type', 'sequence', 'window', 'type' ] => (is => 'ro', isa => 'Int');
+has [ 'response_type', 'sequence', 'pad0', 'window', 'type' ] => (is => 'ro', isa => 'Int');
 has 'data' => (is => 'ro', isa => 'Str');
 
 __PACKAGE__->meta->make_immutable;
